@@ -1977,84 +1977,84 @@ dpoisinvgauss(RpoisinvgaussInf, mean = Inf, dispersion = 1.1)
 
 ## Check q<dist>(p<dist>(.)) identity
 stopifnot(exprs = {
-    All.eq(Rztpois,      qztpois     (Pztpois,      lambda = 12))
-    All.eq(Rztnbinom,    qztnbinom   (Pztnbinom,    size = 7, prob = 0.01))
-    All.eq(Rztgeom,      qztgeom     (Pztgeom,      prob = pi/16))
-    All.eq(Rztbinom,     qztbinom    (Pztbinom,     size = 55, prob = pi/16))
-    All.eq(Rlogarithmic, qlogarithmic(Plogarithmic, prob = 0.99))
-    All.eq(Rzmpoisp0lt,        qzmpois       (Pzmpoisp0lt,        lambda = 6, p0 = 0.001))
-    All.eq(Rzmpoisp0gt,        qzmpois       (Pzmpoisp0gt,        lambda = 6, p0 = 0.010))
-    All.eq(Rzmnbinomp0lt,      qzmnbinom     (Pzmnbinomp0lt,      size = 7, prob = 0.8, p0 = 0.01))
-    All.eq(Rzmnbinomp0gt,      qzmnbinom     (Pzmnbinomp0gt,      size = 7, prob = 0.8, p0 = 0.40))
-    All.eq(Rzmgeomp0lt,        qzmgeom       (Pzmgeomp0lt,        prob = pi/16, p0 = 0.01))
-    All.eq(Rzmgeomp0gt,        qzmgeom       (Pzmgeomp0gt,        prob = pi/16, p0 = 0.40))
-    All.eq(Rzmbinomp0lt,       qzmbinom      (Pzmbinomp0lt,       size = 12, prob = pi/16, p0 = 0.01))
-    All.eq(Rzmbinomp0gt,       qzmbinom      (Pzmbinomp0gt,       size = 12, prob = pi/16, p0 = 0.12))
-    All.eq(Rzmlogarithmicp0lt, qzmlogarithmic(Pzmlogarithmicp0lt, prob = 0.99, p0 = 0.05))
-    All.eq(Rzmlogarithmicp0gt, qzmlogarithmic(Pzmlogarithmicp0gt, prob = 0.99, p0 = 0.55))
-    All.eq(Rpoisinvgauss,    qpoisinvgauss(Ppoisinvgauss,    mean = 12,  dispersion = 0.1))
-    All.eq(RpoisinvgaussInf, qpoisinvgauss(PpoisinvgaussInf, mean = Inf, dispersion = 1.1))
+    Rztpois      == qztpois     (Pztpois,      lambda = 12)
+    Rztnbinom    == qztnbinom   (Pztnbinom,    size = 7, prob = 0.01)
+    Rztgeom      == qztgeom     (Pztgeom,      prob = pi/16)
+    Rztbinom     == qztbinom    (Pztbinom,     size = 55, prob = pi/16)
+    Rlogarithmic == qlogarithmic(Plogarithmic, prob = 0.99)
+    Rzmpoisp0lt        == qzmpois       (Pzmpoisp0lt,        lambda = 6, p0 = 0.001)
+    Rzmpoisp0gt        == qzmpois       (Pzmpoisp0gt,        lambda = 6, p0 = 0.010)
+    Rzmnbinomp0lt      == qzmnbinom     (Pzmnbinomp0lt,      size = 7, prob = 0.8, p0 = 0.01)
+    Rzmnbinomp0gt      == qzmnbinom     (Pzmnbinomp0gt,      size = 7, prob = 0.8, p0 = 0.40)
+    Rzmgeomp0lt        == qzmgeom       (Pzmgeomp0lt,        prob = pi/16, p0 = 0.01)
+    Rzmgeomp0gt        == qzmgeom       (Pzmgeomp0gt,        prob = pi/16, p0 = 0.40)
+    Rzmbinomp0lt       == qzmbinom      (Pzmbinomp0lt,       size = 12, prob = pi/16, p0 = 0.01)
+    Rzmbinomp0gt       == qzmbinom      (Pzmbinomp0gt,       size = 12, prob = pi/16, p0 = 0.12)
+    Rzmlogarithmicp0lt == qzmlogarithmic(Pzmlogarithmicp0lt, prob = 0.99, p0 = 0.05)
+    Rzmlogarithmicp0gt == qzmlogarithmic(Pzmlogarithmicp0gt, prob = 0.99, p0 = 0.55)
+    Rpoisinvgauss    == qpoisinvgauss(Ppoisinvgauss,    mean = 12,  dispersion = 0.1)
+    RpoisinvgaussInf == qpoisinvgauss(PpoisinvgaussInf, mean = Inf, dispersion = 1.1)
 })
 
 ## Check q<dist>(p<dist>(.)) identity with upper tail
 stopifnot(exprs = {
-    All.eq(Rztpois,      qztpois     (1 - Pztpois,      lambda = 12, lower = FALSE))
-    All.eq(Rztnbinom,    qztnbinom   (1 - Pztnbinom,    size = 7, prob = 0.01, lower = FALSE))
-    All.eq(Rztgeom,      qztgeom     (1 - Pztgeom,      prob = pi/16, lower = FALSE))
-    All.eq(Rztbinom,     qztbinom    (1 - Pztbinom,     size = 55, prob = pi/16, lower = FALSE))
-    All.eq(Rlogarithmic, qlogarithmic(1 - Plogarithmic, prob = 0.99, lower = FALSE))
-    All.eq(Rzmpoisp0lt,        qzmpois       (1 - Pzmpoisp0lt,        lambda = 6, p0 = 0.001, lower = FALSE))
-    All.eq(Rzmpoisp0gt,        qzmpois       (1 - Pzmpoisp0gt,        lambda = 6, p0 = 0.010, lower = FALSE))
-    All.eq(Rzmnbinomp0lt,      qzmnbinom     (1 - Pzmnbinomp0lt,      size = 7, prob = 0.8, p0 = 0.01, lower = FALSE))
-    All.eq(Rzmnbinomp0gt,      qzmnbinom     (1 - Pzmnbinomp0gt,      size = 7, prob = 0.8, p0 = 0.40, lower = FALSE))
-    All.eq(Rzmgeomp0lt,        qzmgeom       (1 - Pzmgeomp0lt,        prob = pi/16, p0 = 0.01, lower = FALSE))
-    All.eq(Rzmgeomp0gt,        qzmgeom       (1 - Pzmgeomp0gt,        prob = pi/16, p0 = 0.40, lower = FALSE))
-    All.eq(Rzmbinomp0lt,       qzmbinom      (1 - Pzmbinomp0lt,       size = 12, prob = pi/16, p0 = 0.01, lower = FALSE))
-    All.eq(Rzmbinomp0gt,       qzmbinom      (1 - Pzmbinomp0gt,       size = 12, prob = pi/16, p0 = 0.12, lower = FALSE))
-    All.eq(Rzmlogarithmicp0lt, qzmlogarithmic(1 - Pzmlogarithmicp0lt, prob = 0.99, p0 = 0.05, lower = FALSE))
-    All.eq(Rzmlogarithmicp0gt, qzmlogarithmic(1 - Pzmlogarithmicp0gt, prob = 0.99, p0 = 0.55, lower = FALSE))
-    All.eq(Rpoisinvgauss,    qpoisinvgauss(1 - Ppoisinvgauss,    mean = 12,  dispersion = 0.1, lower = FALSE))
-    All.eq(RpoisinvgaussInf, qpoisinvgauss(1 - PpoisinvgaussInf, mean = Inf, dispersion = 1.1, lower = FALSE))
+    Rztpois      == qztpois     (1 - Pztpois,      lambda = 12, lower = FALSE)
+    Rztnbinom    == qztnbinom   (1 - Pztnbinom,    size = 7, prob = 0.01, lower = FALSE)
+    Rztgeom      == qztgeom     (1 - Pztgeom,      prob = pi/16, lower = FALSE)
+    Rztbinom     == qztbinom    (1 - Pztbinom,     size = 55, prob = pi/16, lower = FALSE)
+    Rlogarithmic == qlogarithmic(1 - Plogarithmic, prob = 0.99, lower = FALSE)
+    Rzmpoisp0lt        == qzmpois       (1 - Pzmpoisp0lt,        lambda = 6, p0 = 0.001, lower = FALSE)
+    Rzmpoisp0gt        == qzmpois       (1 - Pzmpoisp0gt,        lambda = 6, p0 = 0.010, lower = FALSE)
+    Rzmnbinomp0lt      == qzmnbinom     (1 - Pzmnbinomp0lt,      size = 7, prob = 0.8, p0 = 0.01, lower = FALSE)
+    Rzmnbinomp0gt      == qzmnbinom     (1 - Pzmnbinomp0gt,      size = 7, prob = 0.8, p0 = 0.40, lower = FALSE)
+    Rzmgeomp0lt        == qzmgeom       (1 - Pzmgeomp0lt,        prob = pi/16, p0 = 0.01, lower = FALSE)
+    Rzmgeomp0gt        == qzmgeom       (1 - Pzmgeomp0gt,        prob = pi/16, p0 = 0.40, lower = FALSE)
+    Rzmbinomp0lt       == qzmbinom      (1 - Pzmbinomp0lt,       size = 12, prob = pi/16, p0 = 0.01, lower = FALSE)
+    Rzmbinomp0gt       == qzmbinom      (1 - Pzmbinomp0gt,       size = 12, prob = pi/16, p0 = 0.12, lower = FALSE)
+    Rzmlogarithmicp0lt == qzmlogarithmic(1 - Pzmlogarithmicp0lt, prob = 0.99, p0 = 0.05, lower = FALSE)
+    Rzmlogarithmicp0gt == qzmlogarithmic(1 - Pzmlogarithmicp0gt, prob = 0.99, p0 = 0.55, lower = FALSE)
+    Rpoisinvgauss    == qpoisinvgauss(1 - Ppoisinvgauss,    mean = 12,  dispersion = 0.1, lower = FALSE)
+    RpoisinvgaussInf == qpoisinvgauss(1 - PpoisinvgaussInf, mean = Inf, dispersion = 1.1, lower = FALSE)
 })
 
 ## Check q<dist>(p<dist>(., log), log) identity
 stopifnot(exprs = {
-    All.eq(Rztpois,      qztpois     (log(Pztpois),      lambda = 12, log = TRUE))
-    All.eq(Rztnbinom,    qztnbinom   (log(Pztnbinom),    size = 7, prob = 0.01, log = TRUE))
-    All.eq(Rztgeom,      qztgeom     (log(Pztgeom),      prob = pi/16, log = TRUE))
-    All.eq(Rztbinom,     qztbinom    (log(Pztbinom),     size = 55, prob = pi/16, log = TRUE))
-    All.eq(Rlogarithmic, qlogarithmic(log(Plogarithmic), prob = 0.99, log = TRUE))
-    All.eq(Rzmpoisp0lt,        qzmpois       (log(Pzmpoisp0lt),        lambda = 6, p0 = 0.001, log = TRUE))
-    All.eq(Rzmpoisp0gt,        qzmpois       (log(Pzmpoisp0gt),        lambda = 6, p0 = 0.010, log = TRUE))
-    All.eq(Rzmnbinomp0lt,      qzmnbinom     (log(Pzmnbinomp0lt),      size = 7, prob = 0.8, p0 = 0.01, log = TRUE))
-    All.eq(Rzmnbinomp0gt,      qzmnbinom     (log(Pzmnbinomp0gt),      size = 7, prob = 0.8, p0 = 0.40, log = TRUE))
-    All.eq(Rzmgeomp0lt,        qzmgeom       (log(Pzmgeomp0lt),        prob = pi/16, p0 = 0.01, log = TRUE))
-    All.eq(Rzmgeomp0gt,        qzmgeom       (log(Pzmgeomp0gt),        prob = pi/16, p0 = 0.40, log = TRUE))
-    All.eq(Rzmbinomp0lt,       qzmbinom      (log(Pzmbinomp0lt),       size = 12, prob = pi/16, p0 = 0.01, log = TRUE))
-    All.eq(Rzmbinomp0gt,       qzmbinom      (log(Pzmbinomp0gt),       size = 12, prob = pi/16, p0 = 0.12, log = TRUE))
-    All.eq(Rzmlogarithmicp0lt, qzmlogarithmic(log(Pzmlogarithmicp0lt), prob = 0.99, p0 = 0.05, log = TRUE))
-    All.eq(Rzmlogarithmicp0gt, qzmlogarithmic(log(Pzmlogarithmicp0gt), prob = 0.99, p0 = 0.55, log = TRUE))
-    All.eq(Rpoisinvgauss,    qpoisinvgauss(log(Ppoisinvgauss),    mean = 12,  dispersion = 0.1, log = TRUE))
-    All.eq(RpoisinvgaussInf, qpoisinvgauss(log(PpoisinvgaussInf), mean = Inf, dispersion = 1.1, log = TRUE))
+    Rztpois      == qztpois     (log(Pztpois),      lambda = 12, log = TRUE)
+    Rztnbinom    == qztnbinom   (log(Pztnbinom),    size = 7, prob = 0.01, log = TRUE)
+    Rztgeom      == qztgeom     (log(Pztgeom),      prob = pi/16, log = TRUE)
+    Rztbinom     == qztbinom    (log(Pztbinom),     size = 55, prob = pi/16, log = TRUE)
+    Rlogarithmic == qlogarithmic(log(Plogarithmic), prob = 0.99, log = TRUE)
+    Rzmpoisp0lt        == qzmpois       (log(Pzmpoisp0lt),        lambda = 6, p0 = 0.001, log = TRUE)
+    Rzmpoisp0gt        == qzmpois       (log(Pzmpoisp0gt),        lambda = 6, p0 = 0.010, log = TRUE)
+    Rzmnbinomp0lt      == qzmnbinom     (log(Pzmnbinomp0lt),      size = 7, prob = 0.8, p0 = 0.01, log = TRUE)
+    Rzmnbinomp0gt      == qzmnbinom     (log(Pzmnbinomp0gt),      size = 7, prob = 0.8, p0 = 0.40, log = TRUE)
+    Rzmgeomp0lt        == qzmgeom       (log(Pzmgeomp0lt),        prob = pi/16, p0 = 0.01, log = TRUE)
+    Rzmgeomp0gt        == qzmgeom       (log(Pzmgeomp0gt),        prob = pi/16, p0 = 0.40, log = TRUE)
+    Rzmbinomp0lt       == qzmbinom      (log(Pzmbinomp0lt),       size = 12, prob = pi/16, p0 = 0.01, log = TRUE)
+    Rzmbinomp0gt       == qzmbinom      (log(Pzmbinomp0gt),       size = 12, prob = pi/16, p0 = 0.12, log = TRUE)
+    Rzmlogarithmicp0lt == qzmlogarithmic(log(Pzmlogarithmicp0lt), prob = 0.99, p0 = 0.05, log = TRUE)
+    Rzmlogarithmicp0gt == qzmlogarithmic(log(Pzmlogarithmicp0gt), prob = 0.99, p0 = 0.55, log = TRUE)
+    Rpoisinvgauss    == qpoisinvgauss(log(Ppoisinvgauss),    mean = 12,  dispersion = 0.1, log = TRUE)
+    RpoisinvgaussInf == qpoisinvgauss(log(PpoisinvgaussInf), mean = Inf, dispersion = 1.1, log = TRUE)
 })
 
 ## Check q<dist>(p<dist>(., log), log) identity with upper tail
 stopifnot(exprs = {
-    All.eq(Rztpois,      qztpois     (log1p(-Pztpois),      lambda = 12, lower = FALSE, log = TRUE))
-    All.eq(Rztnbinom,    qztnbinom   (log1p(-Pztnbinom),    size = 7, prob = 0.01, lower = FALSE, log = TRUE))
-    All.eq(Rztgeom,      qztgeom     (log1p(-Pztgeom),      prob = pi/16, lower = FALSE, log = TRUE))
-    All.eq(Rztbinom,     qztbinom    (log1p(-Pztbinom),     size = 55, prob = pi/16, lower = FALSE, log = TRUE))
-    All.eq(Rlogarithmic, qlogarithmic(log1p(-Plogarithmic), prob = 0.99, lower = FALSE, log = TRUE))
-    All.eq(Rzmpoisp0lt,        qzmpois       (log1p(-Pzmpoisp0lt),        lambda = 6, p0 = 0.001, lower = FALSE, log = TRUE))
-    All.eq(Rzmpoisp0gt,        qzmpois       (log1p(-Pzmpoisp0gt),        lambda = 6, p0 = 0.010, lower = FALSE, log = TRUE))
-    All.eq(Rzmnbinomp0lt,      qzmnbinom     (log1p(-Pzmnbinomp0lt),      size = 7, prob = 0.8, p0 = 0.01, lower = FALSE, log = TRUE))
-    All.eq(Rzmnbinomp0gt,      qzmnbinom     (log1p(-Pzmnbinomp0gt),      size = 7, prob = 0.8, p0 = 0.40, lower = FALSE, log = TRUE))
-    All.eq(Rzmgeomp0lt,        qzmgeom       (log1p(-Pzmgeomp0lt),        prob = pi/16, p0 = 0.01, lower = FALSE, log = TRUE))
-    All.eq(Rzmgeomp0gt,        qzmgeom       (log1p(-Pzmgeomp0gt),        prob = pi/16, p0 = 0.40, lower = FALSE, log = TRUE))
-    All.eq(Rzmbinomp0lt,       qzmbinom      (log1p(-Pzmbinomp0lt),       size = 12, prob = pi/16, p0 = 0.01, lower = FALSE, log = TRUE))
-    All.eq(Rzmbinomp0gt,       qzmbinom      (log1p(-Pzmbinomp0gt),       size = 12, prob = pi/16, p0 = 0.12, lower = FALSE, log = TRUE))
-    All.eq(Rzmlogarithmicp0lt, qzmlogarithmic(log1p(-Pzmlogarithmicp0lt), prob = 0.99, p0 = 0.05, lower = FALSE, log = TRUE))
-    All.eq(Rzmlogarithmicp0gt, qzmlogarithmic(log1p(-Pzmlogarithmicp0gt), prob = 0.99, p0 = 0.55, lower = FALSE, log = TRUE))
-    All.eq(Rpoisinvgauss,    qpoisinvgauss(log1p(-Ppoisinvgauss),    mean = 12,  dispersion = 0.1, lower = FALSE, log = TRUE))
-    All.eq(RpoisinvgaussInf, qpoisinvgauss(log1p(-PpoisinvgaussInf), mean = Inf, dispersion = 1.1, lower = FALSE, log = TRUE))
+    Rztpois      == qztpois     (log1p(-Pztpois),      lambda = 12, lower = FALSE, log = TRUE)
+    Rztnbinom    == qztnbinom   (log1p(-Pztnbinom),    size = 7, prob = 0.01, lower = FALSE, log = TRUE)
+    Rztgeom      == qztgeom     (log1p(-Pztgeom),      prob = pi/16, lower = FALSE, log = TRUE)
+    Rztbinom     == qztbinom    (log1p(-Pztbinom),     size = 55, prob = pi/16, lower = FALSE, log = TRUE)
+    Rlogarithmic == qlogarithmic(log1p(-Plogarithmic), prob = 0.99, lower = FALSE, log = TRUE)
+    Rzmpoisp0lt        == qzmpois       (log1p(-Pzmpoisp0lt),        lambda = 6, p0 = 0.001, lower = FALSE, log = TRUE)
+    Rzmpoisp0gt        == qzmpois       (log1p(-Pzmpoisp0gt),        lambda = 6, p0 = 0.010, lower = FALSE, log = TRUE)
+    Rzmnbinomp0lt      == qzmnbinom     (log1p(-Pzmnbinomp0lt),      size = 7, prob = 0.8, p0 = 0.01, lower = FALSE, log = TRUE)
+    Rzmnbinomp0gt      == qzmnbinom     (log1p(-Pzmnbinomp0gt),      size = 7, prob = 0.8, p0 = 0.40, lower = FALSE, log = TRUE)
+    Rzmgeomp0lt        == qzmgeom       (log1p(-Pzmgeomp0lt),        prob = pi/16, p0 = 0.01, lower = FALSE, log = TRUE)
+    Rzmgeomp0gt        == qzmgeom       (log1p(-Pzmgeomp0gt),        prob = pi/16, p0 = 0.40, lower = FALSE, log = TRUE)
+    Rzmbinomp0lt       == qzmbinom      (log1p(-Pzmbinomp0lt),       size = 12, prob = pi/16, p0 = 0.01, lower = FALSE, log = TRUE)
+    Rzmbinomp0gt       == qzmbinom      (log1p(-Pzmbinomp0gt),       size = 12, prob = pi/16, p0 = 0.12, lower = FALSE, log = TRUE)
+    Rzmlogarithmicp0lt == qzmlogarithmic(log1p(-Pzmlogarithmicp0lt), prob = 0.99, p0 = 0.05, lower = FALSE, log = TRUE)
+    Rzmlogarithmicp0gt == qzmlogarithmic(log1p(-Pzmlogarithmicp0gt), prob = 0.99, p0 = 0.55, lower = FALSE, log = TRUE)
+    Rpoisinvgauss    == qpoisinvgauss(log1p(-Ppoisinvgauss),    mean = 12,  dispersion = 0.1, lower = FALSE, log = TRUE)
+    RpoisinvgaussInf == qpoisinvgauss(log1p(-PpoisinvgaussInf), mean = Inf, dispersion = 1.1, lower = FALSE, log = TRUE)
 })
